# COPR Ligenix's spec file for glpi-plugin-mreporting
#
# Copyright (c) 2023-2023 Jean-Marc Liger
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname mreporting
%global glpi_min   10.0.0
%global glpi_max   10.1.0

Name:           glpi-plugin-%{pluginname}
Version:        1.8.2
Release:        1%{?dist}
Summary:        GLPI Plugin to add (and develop) new graphical reports
Summary(fr):    Extension GLPI pour ajouter (et développer) de nouveaux rapports grahiques

License:        GPLv2
URL:            https://github.com/pluginsGLPI/%{pluginname}

Source0:        https://github.com/pluginsGLPI/%{pluginname}/releases/download/%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif


%description
This plugins embed a set of new statistics reports:

- Helpdesk
  . Backlog
  . Ticket age
  . Tickets per group or technician
  . Top categories or requester groups
  . Number of group changes
  . 5 SLA reports

- Inventory
  . Os versions and distributions
  .  Top manufacturers
  . Top types (server, laptop, ...)
  . Top status
  . Age of computers
  . FusionInventory agents

- Logs distribution



%description -l fr
Cette extension contient un ensemble de nouveaux rapports statistiques :

- Assistance :
  . Backlog
  . Ancienneté des tickets
  . Tickets par groupes ou techniciens
  . Top catégories ou groupes demandeurs
  . Nombre de changement de groupes
  . 5 rapports SLA

- Inventaire :
  . Versions et distributions des OS
  . Top fabricants
  . Top types (serveurs, portables, ...)
  . Top statuts
  . Age des ordinateurs
  . Agents FusionInventory

- Répartition des logs


%prep
%setup -q -c

grep 'define("PLUGIN_MREPORTING_M.._GLPI' %{pluginname}/setup.php
 
# remove unused files
rm %{pluginname}/%{pluginname}.xml
rm %{pluginname}/composer.json

# move doc files
mkdir docs
mv %{pluginname}/*.md         docs/
mv %{pluginname}/screenshots/ docs/

# Create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs/*
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/ajax
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/fonts
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/js
%{_datadir}/glpi/plugins/%{pluginname}/lib
%{_datadir}/glpi/plugins/%{pluginname}/pics
%{_datadir}/glpi/plugins/%{pluginname}/templates
%{_datadir}/glpi/plugins/%{pluginname}/vendor
# data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Wed May 03 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.8.2-1
- Version 1.8.2 for GLPI 10.0.x

* Wed May 03 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.7.4-1
- Version 1.7.4 for GLPI 9.5.x
- Initial RPM based on Remi Collet previous GLPI plugins spec files
